/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/
'use strict';
define(["require", "exports"], function (require, exports) {
    var OccurrencesSupport = (function () {
        function OccurrencesSupport(client) {
            this.client = client;
        }
        OccurrencesSupport.prototype.findOccurrences = function (resource, position, token) {
            var args = {
                file: this.client.asAbsolutePath(resource),
                line: position.lineNumber,
                offset: position.column
            };
            if (!args.file) {
                return Promise.resolve([]);
            }
            return this.client.execute('occurrences', args, token).then(function (response) {
                var data = response.body;
                if (data) {
                    return data.map(function (item) {
                        return {
                            kind: item.isWriteAccess ? 'write' : null,
                            range: {
                                startLineNumber: item.start.line,
                                startColumn: item.start.offset,
                                endLineNumber: item.end.line,
                                endColumn: item.end.offset
                            }
                        };
                    });
                }
            }, function (err) {
                return [];
            });
        };
        return OccurrencesSupport;
    })();
    return OccurrencesSupport;
});
//# sourceMappingURL=occurrencesSupport.js.map